# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDhcpDetails(object):
    """
    CreateDhcpDetails model.
    """

    #: A constant which can be used with the domain_name_type property of a CreateDhcpDetails.
    #: This constant has a value of "SUBNET_DOMAIN"
    DOMAIN_NAME_TYPE_SUBNET_DOMAIN = "SUBNET_DOMAIN"

    #: A constant which can be used with the domain_name_type property of a CreateDhcpDetails.
    #: This constant has a value of "VCN_DOMAIN"
    DOMAIN_NAME_TYPE_VCN_DOMAIN = "VCN_DOMAIN"

    #: A constant which can be used with the domain_name_type property of a CreateDhcpDetails.
    #: This constant has a value of "CUSTOM_DOMAIN"
    DOMAIN_NAME_TYPE_CUSTOM_DOMAIN = "CUSTOM_DOMAIN"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDhcpDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDhcpDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDhcpDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateDhcpDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDhcpDetails.
        :type freeform_tags: dict(str, str)

        :param options:
            The value to assign to the options property of this CreateDhcpDetails.
        :type options: list[oci.core.models.DhcpOption]

        :param vcn_id:
            The value to assign to the vcn_id property of this CreateDhcpDetails.
        :type vcn_id: str

        :param domain_name_type:
            The value to assign to the domain_name_type property of this CreateDhcpDetails.
            Allowed values for this property are: "SUBNET_DOMAIN", "VCN_DOMAIN", "CUSTOM_DOMAIN"
        :type domain_name_type: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'options': 'list[DhcpOption]',
            'vcn_id': 'str',
            'domain_name_type': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'options': 'options',
            'vcn_id': 'vcnId',
            'domain_name_type': 'domainNameType'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._options = None
        self._vcn_id = None
        self._domain_name_type = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDhcpDetails.
        The OCID of the compartment to contain the set of DHCP options.


        :return: The compartment_id of this CreateDhcpDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDhcpDetails.
        The OCID of the compartment to contain the set of DHCP options.


        :param compartment_id: The compartment_id of this CreateDhcpDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDhcpDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateDhcpDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDhcpDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateDhcpDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateDhcpDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateDhcpDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDhcpDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateDhcpDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDhcpDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateDhcpDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDhcpDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateDhcpDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def options(self):
        """
        **[Required]** Gets the options of this CreateDhcpDetails.
        A set of DHCP options.


        :return: The options of this CreateDhcpDetails.
        :rtype: list[oci.core.models.DhcpOption]
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this CreateDhcpDetails.
        A set of DHCP options.


        :param options: The options of this CreateDhcpDetails.
        :type: list[oci.core.models.DhcpOption]
        """
        self._options = options

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this CreateDhcpDetails.
        The OCID of the VCN the set of DHCP options belongs to.


        :return: The vcn_id of this CreateDhcpDetails.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this CreateDhcpDetails.
        The OCID of the VCN the set of DHCP options belongs to.


        :param vcn_id: The vcn_id of this CreateDhcpDetails.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def domain_name_type(self):
        """
        Gets the domain_name_type of this CreateDhcpDetails.
        The search domain name type of DHCP options

        Allowed values for this property are: "SUBNET_DOMAIN", "VCN_DOMAIN", "CUSTOM_DOMAIN"


        :return: The domain_name_type of this CreateDhcpDetails.
        :rtype: str
        """
        return self._domain_name_type

    @domain_name_type.setter
    def domain_name_type(self, domain_name_type):
        """
        Sets the domain_name_type of this CreateDhcpDetails.
        The search domain name type of DHCP options


        :param domain_name_type: The domain_name_type of this CreateDhcpDetails.
        :type: str
        """
        allowed_values = ["SUBNET_DOMAIN", "VCN_DOMAIN", "CUSTOM_DOMAIN"]
        if not value_allowed_none_or_none_sentinel(domain_name_type, allowed_values):
            raise ValueError(
                "Invalid value for `domain_name_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._domain_name_type = domain_name_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationLaunchInstancePlatformConfig(object):
    """
    The platform configuration requested for the instance.

    If you provide the parameter, the instance is created with the platform configuration that you specify.
    For any values that you omit, the instance uses the default configuration values for the `shape` that you
    specify. If you don't provide the parameter, the default values for the `shape` are used.

    Each shape only supports certain configurable values. If the values that you provide are not valid for the
    specified `shape`, an error is returned.
    """

    #: A constant which can be used with the type property of a InstanceConfigurationLaunchInstancePlatformConfig.
    #: This constant has a value of "AMD_MILAN_BM"
    TYPE_AMD_MILAN_BM = "AMD_MILAN_BM"

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationLaunchInstancePlatformConfig object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.core.models.InstanceConfigurationAmdMilanBmLaunchInstancePlatformConfig`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this InstanceConfigurationLaunchInstancePlatformConfig.
            Allowed values for this property are: "AMD_MILAN_BM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        """
        self.swagger_types = {
            'type': 'str'
        }

        self.attribute_map = {
            'type': 'type'
        }

        self._type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'AMD_MILAN_BM':
            return 'InstanceConfigurationAmdMilanBmLaunchInstancePlatformConfig'
        else:
            return 'InstanceConfigurationLaunchInstancePlatformConfig'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this InstanceConfigurationLaunchInstancePlatformConfig.
        The type of platform being configured. The only supported
        `type` is `AMD_MILAN_BM`.

        Allowed values for this property are: "AMD_MILAN_BM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this InstanceConfigurationLaunchInstancePlatformConfig.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this InstanceConfigurationLaunchInstancePlatformConfig.
        The type of platform being configured. The only supported
        `type` is `AMD_MILAN_BM`.


        :param type: The type of this InstanceConfigurationLaunchInstancePlatformConfig.
        :type: str
        """
        allowed_values = ["AMD_MILAN_BM"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JreUsage(object):
    """
    Java Runtime usage during a specified time period. A Java Runtime is identified by its vendor and version.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JreUsage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param vendor:
            The value to assign to the vendor property of this JreUsage.
        :type vendor: str

        :param distribution:
            The value to assign to the distribution property of this JreUsage.
        :type distribution: str

        :param version:
            The value to assign to the version property of this JreUsage.
        :type version: str

        :param approximate_installation_count:
            The value to assign to the approximate_installation_count property of this JreUsage.
        :type approximate_installation_count: int

        :param approximate_application_count:
            The value to assign to the approximate_application_count property of this JreUsage.
        :type approximate_application_count: int

        :param approximate_managed_instance_count:
            The value to assign to the approximate_managed_instance_count property of this JreUsage.
        :type approximate_managed_instance_count: int

        :param time_start:
            The value to assign to the time_start property of this JreUsage.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this JreUsage.
        :type time_end: datetime

        :param time_first_seen:
            The value to assign to the time_first_seen property of this JreUsage.
        :type time_first_seen: datetime

        :param time_last_seen:
            The value to assign to the time_last_seen property of this JreUsage.
        :type time_last_seen: datetime

        """
        self.swagger_types = {
            'vendor': 'str',
            'distribution': 'str',
            'version': 'str',
            'approximate_installation_count': 'int',
            'approximate_application_count': 'int',
            'approximate_managed_instance_count': 'int',
            'time_start': 'datetime',
            'time_end': 'datetime',
            'time_first_seen': 'datetime',
            'time_last_seen': 'datetime'
        }

        self.attribute_map = {
            'vendor': 'vendor',
            'distribution': 'distribution',
            'version': 'version',
            'approximate_installation_count': 'approximateInstallationCount',
            'approximate_application_count': 'approximateApplicationCount',
            'approximate_managed_instance_count': 'approximateManagedInstanceCount',
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'time_first_seen': 'timeFirstSeen',
            'time_last_seen': 'timeLastSeen'
        }

        self._vendor = None
        self._distribution = None
        self._version = None
        self._approximate_installation_count = None
        self._approximate_application_count = None
        self._approximate_managed_instance_count = None
        self._time_start = None
        self._time_end = None
        self._time_first_seen = None
        self._time_last_seen = None

    @property
    def vendor(self):
        """
        **[Required]** Gets the vendor of this JreUsage.
        The vendor of the Java Runtime.


        :return: The vendor of this JreUsage.
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """
        Sets the vendor of this JreUsage.
        The vendor of the Java Runtime.


        :param vendor: The vendor of this JreUsage.
        :type: str
        """
        self._vendor = vendor

    @property
    def distribution(self):
        """
        **[Required]** Gets the distribution of this JreUsage.
        The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.


        :return: The distribution of this JreUsage.
        :rtype: str
        """
        return self._distribution

    @distribution.setter
    def distribution(self, distribution):
        """
        Sets the distribution of this JreUsage.
        The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.


        :param distribution: The distribution of this JreUsage.
        :type: str
        """
        self._distribution = distribution

    @property
    def version(self):
        """
        **[Required]** Gets the version of this JreUsage.
        The version of the Java Runtime.


        :return: The version of this JreUsage.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this JreUsage.
        The version of the Java Runtime.


        :param version: The version of this JreUsage.
        :type: str
        """
        self._version = version

    @property
    def approximate_installation_count(self):
        """
        Gets the approximate_installation_count of this JreUsage.
        The approximate count of installations that are installations of this Java Runtime.


        :return: The approximate_installation_count of this JreUsage.
        :rtype: int
        """
        return self._approximate_installation_count

    @approximate_installation_count.setter
    def approximate_installation_count(self, approximate_installation_count):
        """
        Sets the approximate_installation_count of this JreUsage.
        The approximate count of installations that are installations of this Java Runtime.


        :param approximate_installation_count: The approximate_installation_count of this JreUsage.
        :type: int
        """
        self._approximate_installation_count = approximate_installation_count

    @property
    def approximate_application_count(self):
        """
        Gets the approximate_application_count of this JreUsage.
        The approximate count of the applications running on this Java Runtime.


        :return: The approximate_application_count of this JreUsage.
        :rtype: int
        """
        return self._approximate_application_count

    @approximate_application_count.setter
    def approximate_application_count(self, approximate_application_count):
        """
        Sets the approximate_application_count of this JreUsage.
        The approximate count of the applications running on this Java Runtime.


        :param approximate_application_count: The approximate_application_count of this JreUsage.
        :type: int
        """
        self._approximate_application_count = approximate_application_count

    @property
    def approximate_managed_instance_count(self):
        """
        Gets the approximate_managed_instance_count of this JreUsage.
        The approximate count of the managed instances that report this Java Runtime.


        :return: The approximate_managed_instance_count of this JreUsage.
        :rtype: int
        """
        return self._approximate_managed_instance_count

    @approximate_managed_instance_count.setter
    def approximate_managed_instance_count(self, approximate_managed_instance_count):
        """
        Sets the approximate_managed_instance_count of this JreUsage.
        The approximate count of the managed instances that report this Java Runtime.


        :param approximate_managed_instance_count: The approximate_managed_instance_count of this JreUsage.
        :type: int
        """
        self._approximate_managed_instance_count = approximate_managed_instance_count

    @property
    def time_start(self):
        """
        Gets the time_start of this JreUsage.
        Lower bound of the specified time period filter.


        :return: The time_start of this JreUsage.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this JreUsage.
        Lower bound of the specified time period filter.


        :param time_start: The time_start of this JreUsage.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this JreUsage.
        Upper bound of the specified time period filter.


        :return: The time_end of this JreUsage.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this JreUsage.
        Upper bound of the specified time period filter.


        :param time_end: The time_end of this JreUsage.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def time_first_seen(self):
        """
        Gets the time_first_seen of this JreUsage.
        The date and time the resource was _first_ reported to JMS.
        This is potentially _before_ the specified time period provided by the filters.
        For example, a resource can be first reported to JMS before the start of a specified time period,
        if it is also reported during the time period.


        :return: The time_first_seen of this JreUsage.
        :rtype: datetime
        """
        return self._time_first_seen

    @time_first_seen.setter
    def time_first_seen(self, time_first_seen):
        """
        Sets the time_first_seen of this JreUsage.
        The date and time the resource was _first_ reported to JMS.
        This is potentially _before_ the specified time period provided by the filters.
        For example, a resource can be first reported to JMS before the start of a specified time period,
        if it is also reported during the time period.


        :param time_first_seen: The time_first_seen of this JreUsage.
        :type: datetime
        """
        self._time_first_seen = time_first_seen

    @property
    def time_last_seen(self):
        """
        Gets the time_last_seen of this JreUsage.
        The date and time the resource was _last_ reported to JMS.
        This is potentially _after_ the specified time period provided by the filters.
        For example, a resource can be last reported to JMS before the start of a specified time period,
        if it is also reported during the time period.


        :return: The time_last_seen of this JreUsage.
        :rtype: datetime
        """
        return self._time_last_seen

    @time_last_seen.setter
    def time_last_seen(self, time_last_seen):
        """
        Sets the time_last_seen of this JreUsage.
        The date and time the resource was _last_ reported to JMS.
        This is potentially _after_ the specified time period provided by the filters.
        For example, a resource can be last reported to JMS before the start of a specified time period,
        if it is also reported during the time period.


        :param time_last_seen: The time_last_seen of this JreUsage.
        :type: datetime
        """
        self._time_last_seen = time_last_seen

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Forecast(object):
    """
    Forecast configuration of usage/cost.
    """

    #: A constant which can be used with the forecast_type property of a Forecast.
    #: This constant has a value of "BASIC"
    FORECAST_TYPE_BASIC = "BASIC"

    def __init__(self, **kwargs):
        """
        Initializes a new Forecast object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param forecast_type:
            The value to assign to the forecast_type property of this Forecast.
            Allowed values for this property are: "BASIC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type forecast_type: str

        :param time_forecast_started:
            The value to assign to the time_forecast_started property of this Forecast.
        :type time_forecast_started: datetime

        :param time_forecast_ended:
            The value to assign to the time_forecast_ended property of this Forecast.
        :type time_forecast_ended: datetime

        """
        self.swagger_types = {
            'forecast_type': 'str',
            'time_forecast_started': 'datetime',
            'time_forecast_ended': 'datetime'
        }

        self.attribute_map = {
            'forecast_type': 'forecastType',
            'time_forecast_started': 'timeForecastStarted',
            'time_forecast_ended': 'timeForecastEnded'
        }

        self._forecast_type = None
        self._time_forecast_started = None
        self._time_forecast_ended = None

    @property
    def forecast_type(self):
        """
        Gets the forecast_type of this Forecast.
        BASIC uses the exponential smoothing (ETS) model to project future usage/costs based on history data. The basis for projections is a periodic set of equivalent historical days for which the projection is being made.

        Allowed values for this property are: "BASIC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The forecast_type of this Forecast.
        :rtype: str
        """
        return self._forecast_type

    @forecast_type.setter
    def forecast_type(self, forecast_type):
        """
        Sets the forecast_type of this Forecast.
        BASIC uses the exponential smoothing (ETS) model to project future usage/costs based on history data. The basis for projections is a periodic set of equivalent historical days for which the projection is being made.


        :param forecast_type: The forecast_type of this Forecast.
        :type: str
        """
        allowed_values = ["BASIC"]
        if not value_allowed_none_or_none_sentinel(forecast_type, allowed_values):
            forecast_type = 'UNKNOWN_ENUM_VALUE'
        self._forecast_type = forecast_type

    @property
    def time_forecast_started(self):
        """
        Gets the time_forecast_started of this Forecast.
        The forecast start time. Defaults to UTC-1 if not specified.


        :return: The time_forecast_started of this Forecast.
        :rtype: datetime
        """
        return self._time_forecast_started

    @time_forecast_started.setter
    def time_forecast_started(self, time_forecast_started):
        """
        Sets the time_forecast_started of this Forecast.
        The forecast start time. Defaults to UTC-1 if not specified.


        :param time_forecast_started: The time_forecast_started of this Forecast.
        :type: datetime
        """
        self._time_forecast_started = time_forecast_started

    @property
    def time_forecast_ended(self):
        """
        **[Required]** Gets the time_forecast_ended of this Forecast.
        The forecast end time.


        :return: The time_forecast_ended of this Forecast.
        :rtype: datetime
        """
        return self._time_forecast_ended

    @time_forecast_ended.setter
    def time_forecast_ended(self, time_forecast_ended):
        """
        Sets the time_forecast_ended of this Forecast.
        The forecast end time.


        :param time_forecast_ended: The time_forecast_ended of this Forecast.
        :type: datetime
        """
        self._time_forecast_ended = time_forecast_ended

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitorStatusCountMap(object):
    """
    Details of the monitor count per state.
    Example: `{ \"total\" : 5, \"enabled\" : 3 , \"disabled\" : 2, \"invalid\" : 0 }`
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitorStatusCountMap object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total:
            The value to assign to the total property of this MonitorStatusCountMap.
        :type total: int

        :param enabled:
            The value to assign to the enabled property of this MonitorStatusCountMap.
        :type enabled: int

        :param disabled:
            The value to assign to the disabled property of this MonitorStatusCountMap.
        :type disabled: int

        :param invalid:
            The value to assign to the invalid property of this MonitorStatusCountMap.
        :type invalid: int

        """
        self.swagger_types = {
            'total': 'int',
            'enabled': 'int',
            'disabled': 'int',
            'invalid': 'int'
        }

        self.attribute_map = {
            'total': 'total',
            'enabled': 'enabled',
            'disabled': 'disabled',
            'invalid': 'invalid'
        }

        self._total = None
        self._enabled = None
        self._disabled = None
        self._invalid = None

    @property
    def total(self):
        """
        **[Required]** Gets the total of this MonitorStatusCountMap.
        Total number of monitors using the script.


        :return: The total of this MonitorStatusCountMap.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this MonitorStatusCountMap.
        Total number of monitors using the script.


        :param total: The total of this MonitorStatusCountMap.
        :type: int
        """
        self._total = total

    @property
    def enabled(self):
        """
        **[Required]** Gets the enabled of this MonitorStatusCountMap.
        Number of enabled monitors using the script.


        :return: The enabled of this MonitorStatusCountMap.
        :rtype: int
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this MonitorStatusCountMap.
        Number of enabled monitors using the script.


        :param enabled: The enabled of this MonitorStatusCountMap.
        :type: int
        """
        self._enabled = enabled

    @property
    def disabled(self):
        """
        **[Required]** Gets the disabled of this MonitorStatusCountMap.
        Number of disabled monitors using the script.


        :return: The disabled of this MonitorStatusCountMap.
        :rtype: int
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """
        Sets the disabled of this MonitorStatusCountMap.
        Number of disabled monitors using the script.


        :param disabled: The disabled of this MonitorStatusCountMap.
        :type: int
        """
        self._disabled = disabled

    @property
    def invalid(self):
        """
        **[Required]** Gets the invalid of this MonitorStatusCountMap.
        Number of invalid monitors using the script.


        :return: The invalid of this MonitorStatusCountMap.
        :rtype: int
        """
        return self._invalid

    @invalid.setter
    def invalid(self, invalid):
        """
        Sets the invalid of this MonitorStatusCountMap.
        Number of invalid monitors using the script.


        :param invalid: The invalid of this MonitorStatusCountMap.
        :type: int
        """
        self._invalid = invalid

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OperatorControlAssignment(object):
    """
    An Operator Control Assignment identifies the target resource that is placed under the governance of an Operator Control. Creating an Operator Control Assignment Assignment with a time duration ensures that
    human accesses to the target resource will be governed by Operator Control for the duration specified.
    """

    #: A constant which can be used with the resource_type property of a OperatorControlAssignment.
    #: This constant has a value of "EXACC"
    RESOURCE_TYPE_EXACC = "EXACC"

    #: A constant which can be used with the lifecycle_state property of a OperatorControlAssignment.
    #: This constant has a value of "CREATED"
    LIFECYCLE_STATE_CREATED = "CREATED"

    #: A constant which can be used with the lifecycle_state property of a OperatorControlAssignment.
    #: This constant has a value of "APPLIED"
    LIFECYCLE_STATE_APPLIED = "APPLIED"

    #: A constant which can be used with the lifecycle_state property of a OperatorControlAssignment.
    #: This constant has a value of "APPLYFAILED"
    LIFECYCLE_STATE_APPLYFAILED = "APPLYFAILED"

    #: A constant which can be used with the lifecycle_state property of a OperatorControlAssignment.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new OperatorControlAssignment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this OperatorControlAssignment.
        :type id: str

        :param operator_control_id:
            The value to assign to the operator_control_id property of this OperatorControlAssignment.
        :type operator_control_id: str

        :param resource_id:
            The value to assign to the resource_id property of this OperatorControlAssignment.
        :type resource_id: str

        :param resource_name:
            The value to assign to the resource_name property of this OperatorControlAssignment.
        :type resource_name: str

        :param resource_type:
            The value to assign to the resource_type property of this OperatorControlAssignment.
            Allowed values for this property are: "EXACC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type resource_type: str

        :param resource_compartment_id:
            The value to assign to the resource_compartment_id property of this OperatorControlAssignment.
        :type resource_compartment_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this OperatorControlAssignment.
        :type compartment_id: str

        :param time_assignment_from:
            The value to assign to the time_assignment_from property of this OperatorControlAssignment.
        :type time_assignment_from: datetime

        :param time_assignment_to:
            The value to assign to the time_assignment_to property of this OperatorControlAssignment.
        :type time_assignment_to: datetime

        :param is_enforced_always:
            The value to assign to the is_enforced_always property of this OperatorControlAssignment.
        :type is_enforced_always: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this OperatorControlAssignment.
            Allowed values for this property are: "CREATED", "APPLIED", "APPLYFAILED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param assigner_id:
            The value to assign to the assigner_id property of this OperatorControlAssignment.
        :type assigner_id: str

        :param time_of_assignment:
            The value to assign to the time_of_assignment property of this OperatorControlAssignment.
        :type time_of_assignment: datetime

        :param comment:
            The value to assign to the comment property of this OperatorControlAssignment.
        :type comment: str

        :param unassigner_id:
            The value to assign to the unassigner_id property of this OperatorControlAssignment.
        :type unassigner_id: str

        :param time_of_deletion:
            The value to assign to the time_of_deletion property of this OperatorControlAssignment.
        :type time_of_deletion: datetime

        :param detachment_description:
            The value to assign to the detachment_description property of this OperatorControlAssignment.
        :type detachment_description: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this OperatorControlAssignment.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this OperatorControlAssignment.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'operator_control_id': 'str',
            'resource_id': 'str',
            'resource_name': 'str',
            'resource_type': 'str',
            'resource_compartment_id': 'str',
            'compartment_id': 'str',
            'time_assignment_from': 'datetime',
            'time_assignment_to': 'datetime',
            'is_enforced_always': 'bool',
            'lifecycle_state': 'str',
            'assigner_id': 'str',
            'time_of_assignment': 'datetime',
            'comment': 'str',
            'unassigner_id': 'str',
            'time_of_deletion': 'datetime',
            'detachment_description': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'operator_control_id': 'operatorControlId',
            'resource_id': 'resourceId',
            'resource_name': 'resourceName',
            'resource_type': 'resourceType',
            'resource_compartment_id': 'resourceCompartmentId',
            'compartment_id': 'compartmentId',
            'time_assignment_from': 'timeAssignmentFrom',
            'time_assignment_to': 'timeAssignmentTo',
            'is_enforced_always': 'isEnforcedAlways',
            'lifecycle_state': 'lifecycleState',
            'assigner_id': 'assignerId',
            'time_of_assignment': 'timeOfAssignment',
            'comment': 'comment',
            'unassigner_id': 'unassignerId',
            'time_of_deletion': 'timeOfDeletion',
            'detachment_description': 'detachmentDescription',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._operator_control_id = None
        self._resource_id = None
        self._resource_name = None
        self._resource_type = None
        self._resource_compartment_id = None
        self._compartment_id = None
        self._time_assignment_from = None
        self._time_assignment_to = None
        self._is_enforced_always = None
        self._lifecycle_state = None
        self._assigner_id = None
        self._time_of_assignment = None
        self._comment = None
        self._unassigner_id = None
        self._time_of_deletion = None
        self._detachment_description = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this OperatorControlAssignment.
        The OCID of the operator control assignment.


        :return: The id of this OperatorControlAssignment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OperatorControlAssignment.
        The OCID of the operator control assignment.


        :param id: The id of this OperatorControlAssignment.
        :type: str
        """
        self._id = id

    @property
    def operator_control_id(self):
        """
        **[Required]** Gets the operator_control_id of this OperatorControlAssignment.
        The OCID of the operator control.


        :return: The operator_control_id of this OperatorControlAssignment.
        :rtype: str
        """
        return self._operator_control_id

    @operator_control_id.setter
    def operator_control_id(self, operator_control_id):
        """
        Sets the operator_control_id of this OperatorControlAssignment.
        The OCID of the operator control.


        :param operator_control_id: The operator_control_id of this OperatorControlAssignment.
        :type: str
        """
        self._operator_control_id = operator_control_id

    @property
    def resource_id(self):
        """
        **[Required]** Gets the resource_id of this OperatorControlAssignment.
        The OCID of the target resource.


        :return: The resource_id of this OperatorControlAssignment.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this OperatorControlAssignment.
        The OCID of the target resource.


        :param resource_id: The resource_id of this OperatorControlAssignment.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def resource_name(self):
        """
        **[Required]** Gets the resource_name of this OperatorControlAssignment.
        Name of the target resource.


        :return: The resource_name of this OperatorControlAssignment.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this OperatorControlAssignment.
        Name of the target resource.


        :param resource_name: The resource_name of this OperatorControlAssignment.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def resource_type(self):
        """
        Gets the resource_type of this OperatorControlAssignment.
        Type of the target resource.

        Allowed values for this property are: "EXACC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The resource_type of this OperatorControlAssignment.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this OperatorControlAssignment.
        Type of the target resource.


        :param resource_type: The resource_type of this OperatorControlAssignment.
        :type: str
        """
        allowed_values = ["EXACC"]
        if not value_allowed_none_or_none_sentinel(resource_type, allowed_values):
            resource_type = 'UNKNOWN_ENUM_VALUE'
        self._resource_type = resource_type

    @property
    def resource_compartment_id(self):
        """
        Gets the resource_compartment_id of this OperatorControlAssignment.
        The OCID of the compartment that contains the target resource.


        :return: The resource_compartment_id of this OperatorControlAssignment.
        :rtype: str
        """
        return self._resource_compartment_id

    @resource_compartment_id.setter
    def resource_compartment_id(self, resource_compartment_id):
        """
        Sets the resource_compartment_id of this OperatorControlAssignment.
        The OCID of the compartment that contains the target resource.


        :param resource_compartment_id: The resource_compartment_id of this OperatorControlAssignment.
        :type: str
        """
        self._resource_compartment_id = resource_compartment_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this OperatorControlAssignment.
        The OCID of the comparment that contains the operator control assignment.


        :return: The compartment_id of this OperatorControlAssignment.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this OperatorControlAssignment.
        The OCID of the comparment that contains the operator control assignment.


        :param compartment_id: The compartment_id of this OperatorControlAssignment.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_assignment_from(self):
        """
        Gets the time_assignment_from of this OperatorControlAssignment.
        The time at which the target resource will be brought under the governance of the operator control expressed in `RFC 3339`__ timestamp format.
        Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_assignment_from of this OperatorControlAssignment.
        :rtype: datetime
        """
        return self._time_assignment_from

    @time_assignment_from.setter
    def time_assignment_from(self, time_assignment_from):
        """
        Sets the time_assignment_from of this OperatorControlAssignment.
        The time at which the target resource will be brought under the governance of the operator control expressed in `RFC 3339`__ timestamp format.
        Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :param time_assignment_from: The time_assignment_from of this OperatorControlAssignment.
        :type: datetime
        """
        self._time_assignment_from = time_assignment_from

    @property
    def time_assignment_to(self):
        """
        Gets the time_assignment_to of this OperatorControlAssignment.
        The time at which the target resource will leave the governance of the operator control expressed in `RFC 3339`__ timestamp format.
        Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_assignment_to of this OperatorControlAssignment.
        :rtype: datetime
        """
        return self._time_assignment_to

    @time_assignment_to.setter
    def time_assignment_to(self, time_assignment_to):
        """
        Sets the time_assignment_to of this OperatorControlAssignment.
        The time at which the target resource will leave the governance of the operator control expressed in `RFC 3339`__ timestamp format.
        Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :param time_assignment_to: The time_assignment_to of this OperatorControlAssignment.
        :type: datetime
        """
        self._time_assignment_to = time_assignment_to

    @property
    def is_enforced_always(self):
        """
        Gets the is_enforced_always of this OperatorControlAssignment.
        If set, then the target resource is always governed by the operator control.


        :return: The is_enforced_always of this OperatorControlAssignment.
        :rtype: bool
        """
        return self._is_enforced_always

    @is_enforced_always.setter
    def is_enforced_always(self, is_enforced_always):
        """
        Sets the is_enforced_always of this OperatorControlAssignment.
        If set, then the target resource is always governed by the operator control.


        :param is_enforced_always: The is_enforced_always of this OperatorControlAssignment.
        :type: bool
        """
        self._is_enforced_always = is_enforced_always

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this OperatorControlAssignment.
        The current lifcycle state of the OperatorControl.

        Allowed values for this property are: "CREATED", "APPLIED", "APPLYFAILED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this OperatorControlAssignment.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this OperatorControlAssignment.
        The current lifcycle state of the OperatorControl.


        :param lifecycle_state: The lifecycle_state of this OperatorControlAssignment.
        :type: str
        """
        allowed_values = ["CREATED", "APPLIED", "APPLYFAILED", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def assigner_id(self):
        """
        Gets the assigner_id of this OperatorControlAssignment.
        The OCID of the user who created this operator control assignment.


        :return: The assigner_id of this OperatorControlAssignment.
        :rtype: str
        """
        return self._assigner_id

    @assigner_id.setter
    def assigner_id(self, assigner_id):
        """
        Sets the assigner_id of this OperatorControlAssignment.
        The OCID of the user who created this operator control assignment.


        :param assigner_id: The assigner_id of this OperatorControlAssignment.
        :type: str
        """
        self._assigner_id = assigner_id

    @property
    def time_of_assignment(self):
        """
        Gets the time_of_assignment of this OperatorControlAssignment.
        Time when the operator control assignment is created in `RFC 3339`__ timestamp format. Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_assignment of this OperatorControlAssignment.
        :rtype: datetime
        """
        return self._time_of_assignment

    @time_of_assignment.setter
    def time_of_assignment(self, time_of_assignment):
        """
        Sets the time_of_assignment of this OperatorControlAssignment.
        Time when the operator control assignment is created in `RFC 3339`__ timestamp format. Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_assignment: The time_of_assignment of this OperatorControlAssignment.
        :type: datetime
        """
        self._time_of_assignment = time_of_assignment

    @property
    def comment(self):
        """
        Gets the comment of this OperatorControlAssignment.
        Comment about the assignment of the operator control to this target resource.


        :return: The comment of this OperatorControlAssignment.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """
        Sets the comment of this OperatorControlAssignment.
        Comment about the assignment of the operator control to this target resource.


        :param comment: The comment of this OperatorControlAssignment.
        :type: str
        """
        self._comment = comment

    @property
    def unassigner_id(self):
        """
        Gets the unassigner_id of this OperatorControlAssignment.
        User id who released the operatorControl.


        :return: The unassigner_id of this OperatorControlAssignment.
        :rtype: str
        """
        return self._unassigner_id

    @unassigner_id.setter
    def unassigner_id(self, unassigner_id):
        """
        Sets the unassigner_id of this OperatorControlAssignment.
        User id who released the operatorControl.


        :param unassigner_id: The unassigner_id of this OperatorControlAssignment.
        :type: str
        """
        self._unassigner_id = unassigner_id

    @property
    def time_of_deletion(self):
        """
        Gets the time_of_deletion of this OperatorControlAssignment.
        Time on which the operator control assignment was deleted in `RFC 3339`__timestamp format.Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_deletion of this OperatorControlAssignment.
        :rtype: datetime
        """
        return self._time_of_deletion

    @time_of_deletion.setter
    def time_of_deletion(self, time_of_deletion):
        """
        Sets the time_of_deletion of this OperatorControlAssignment.
        Time on which the operator control assignment was deleted in `RFC 3339`__timestamp format.Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_deletion: The time_of_deletion of this OperatorControlAssignment.
        :type: datetime
        """
        self._time_of_deletion = time_of_deletion

    @property
    def detachment_description(self):
        """
        Gets the detachment_description of this OperatorControlAssignment.
        description containing reason for releasing of OperatorControl.


        :return: The detachment_description of this OperatorControlAssignment.
        :rtype: str
        """
        return self._detachment_description

    @detachment_description.setter
    def detachment_description(self, detachment_description):
        """
        Sets the detachment_description of this OperatorControlAssignment.
        description containing reason for releasing of OperatorControl.


        :param detachment_description: The detachment_description of this OperatorControlAssignment.
        :type: str
        """
        self._detachment_description = detachment_description

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this OperatorControlAssignment.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.


        :return: The freeform_tags of this OperatorControlAssignment.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this OperatorControlAssignment.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.


        :param freeform_tags: The freeform_tags of this OperatorControlAssignment.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this OperatorControlAssignment.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.


        :return: The defined_tags of this OperatorControlAssignment.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this OperatorControlAssignment.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.


        :param defined_tags: The defined_tags of this OperatorControlAssignment.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .response_cache_details import ResponseCacheDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExternalRespCache(ResponseCacheDetails):
    """
    Connection details for an external RESP based cache store for Response Caching.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ExternalRespCache object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.ExternalRespCache.type` attribute
        of this class is ``EXTERNAL_RESP_CACHE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ExternalRespCache.
            Allowed values for this property are: "EXTERNAL_RESP_CACHE", "NONE"
        :type type: str

        :param servers:
            The value to assign to the servers property of this ExternalRespCache.
        :type servers: list[oci.apigateway.models.ResponseCacheRespServer]

        :param authentication_secret_id:
            The value to assign to the authentication_secret_id property of this ExternalRespCache.
        :type authentication_secret_id: str

        :param authentication_secret_version_number:
            The value to assign to the authentication_secret_version_number property of this ExternalRespCache.
        :type authentication_secret_version_number: int

        :param is_ssl_enabled:
            The value to assign to the is_ssl_enabled property of this ExternalRespCache.
        :type is_ssl_enabled: bool

        :param is_ssl_verify_disabled:
            The value to assign to the is_ssl_verify_disabled property of this ExternalRespCache.
        :type is_ssl_verify_disabled: bool

        :param connect_timeout_in_ms:
            The value to assign to the connect_timeout_in_ms property of this ExternalRespCache.
        :type connect_timeout_in_ms: int

        :param read_timeout_in_ms:
            The value to assign to the read_timeout_in_ms property of this ExternalRespCache.
        :type read_timeout_in_ms: int

        :param send_timeout_in_ms:
            The value to assign to the send_timeout_in_ms property of this ExternalRespCache.
        :type send_timeout_in_ms: int

        """
        self.swagger_types = {
            'type': 'str',
            'servers': 'list[ResponseCacheRespServer]',
            'authentication_secret_id': 'str',
            'authentication_secret_version_number': 'int',
            'is_ssl_enabled': 'bool',
            'is_ssl_verify_disabled': 'bool',
            'connect_timeout_in_ms': 'int',
            'read_timeout_in_ms': 'int',
            'send_timeout_in_ms': 'int'
        }

        self.attribute_map = {
            'type': 'type',
            'servers': 'servers',
            'authentication_secret_id': 'authenticationSecretId',
            'authentication_secret_version_number': 'authenticationSecretVersionNumber',
            'is_ssl_enabled': 'isSslEnabled',
            'is_ssl_verify_disabled': 'isSslVerifyDisabled',
            'connect_timeout_in_ms': 'connectTimeoutInMs',
            'read_timeout_in_ms': 'readTimeoutInMs',
            'send_timeout_in_ms': 'sendTimeoutInMs'
        }

        self._type = None
        self._servers = None
        self._authentication_secret_id = None
        self._authentication_secret_version_number = None
        self._is_ssl_enabled = None
        self._is_ssl_verify_disabled = None
        self._connect_timeout_in_ms = None
        self._read_timeout_in_ms = None
        self._send_timeout_in_ms = None
        self._type = 'EXTERNAL_RESP_CACHE'

    @property
    def servers(self):
        """
        **[Required]** Gets the servers of this ExternalRespCache.
        The set of cache store members to connect to. At present only a single server is supported.


        :return: The servers of this ExternalRespCache.
        :rtype: list[oci.apigateway.models.ResponseCacheRespServer]
        """
        return self._servers

    @servers.setter
    def servers(self, servers):
        """
        Sets the servers of this ExternalRespCache.
        The set of cache store members to connect to. At present only a single server is supported.


        :param servers: The servers of this ExternalRespCache.
        :type: list[oci.apigateway.models.ResponseCacheRespServer]
        """
        self._servers = servers

    @property
    def authentication_secret_id(self):
        """
        **[Required]** Gets the authentication_secret_id of this ExternalRespCache.
        The `OCID`__ of the Oracle Vault Service secret resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The authentication_secret_id of this ExternalRespCache.
        :rtype: str
        """
        return self._authentication_secret_id

    @authentication_secret_id.setter
    def authentication_secret_id(self, authentication_secret_id):
        """
        Sets the authentication_secret_id of this ExternalRespCache.
        The `OCID`__ of the Oracle Vault Service secret resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param authentication_secret_id: The authentication_secret_id of this ExternalRespCache.
        :type: str
        """
        self._authentication_secret_id = authentication_secret_id

    @property
    def authentication_secret_version_number(self):
        """
        **[Required]** Gets the authentication_secret_version_number of this ExternalRespCache.
        The version number of the authentication secret to use.


        :return: The authentication_secret_version_number of this ExternalRespCache.
        :rtype: int
        """
        return self._authentication_secret_version_number

    @authentication_secret_version_number.setter
    def authentication_secret_version_number(self, authentication_secret_version_number):
        """
        Sets the authentication_secret_version_number of this ExternalRespCache.
        The version number of the authentication secret to use.


        :param authentication_secret_version_number: The authentication_secret_version_number of this ExternalRespCache.
        :type: int
        """
        self._authentication_secret_version_number = authentication_secret_version_number

    @property
    def is_ssl_enabled(self):
        """
        Gets the is_ssl_enabled of this ExternalRespCache.
        Defines if the connection should be over SSL.


        :return: The is_ssl_enabled of this ExternalRespCache.
        :rtype: bool
        """
        return self._is_ssl_enabled

    @is_ssl_enabled.setter
    def is_ssl_enabled(self, is_ssl_enabled):
        """
        Sets the is_ssl_enabled of this ExternalRespCache.
        Defines if the connection should be over SSL.


        :param is_ssl_enabled: The is_ssl_enabled of this ExternalRespCache.
        :type: bool
        """
        self._is_ssl_enabled = is_ssl_enabled

    @property
    def is_ssl_verify_disabled(self):
        """
        Gets the is_ssl_verify_disabled of this ExternalRespCache.
        Defines whether or not to uphold SSL verification.


        :return: The is_ssl_verify_disabled of this ExternalRespCache.
        :rtype: bool
        """
        return self._is_ssl_verify_disabled

    @is_ssl_verify_disabled.setter
    def is_ssl_verify_disabled(self, is_ssl_verify_disabled):
        """
        Sets the is_ssl_verify_disabled of this ExternalRespCache.
        Defines whether or not to uphold SSL verification.


        :param is_ssl_verify_disabled: The is_ssl_verify_disabled of this ExternalRespCache.
        :type: bool
        """
        self._is_ssl_verify_disabled = is_ssl_verify_disabled

    @property
    def connect_timeout_in_ms(self):
        """
        Gets the connect_timeout_in_ms of this ExternalRespCache.
        Defines the timeout for establishing a connection with the Response Cache.


        :return: The connect_timeout_in_ms of this ExternalRespCache.
        :rtype: int
        """
        return self._connect_timeout_in_ms

    @connect_timeout_in_ms.setter
    def connect_timeout_in_ms(self, connect_timeout_in_ms):
        """
        Sets the connect_timeout_in_ms of this ExternalRespCache.
        Defines the timeout for establishing a connection with the Response Cache.


        :param connect_timeout_in_ms: The connect_timeout_in_ms of this ExternalRespCache.
        :type: int
        """
        self._connect_timeout_in_ms = connect_timeout_in_ms

    @property
    def read_timeout_in_ms(self):
        """
        Gets the read_timeout_in_ms of this ExternalRespCache.
        Defines the timeout for reading data from the Response Cache.


        :return: The read_timeout_in_ms of this ExternalRespCache.
        :rtype: int
        """
        return self._read_timeout_in_ms

    @read_timeout_in_ms.setter
    def read_timeout_in_ms(self, read_timeout_in_ms):
        """
        Sets the read_timeout_in_ms of this ExternalRespCache.
        Defines the timeout for reading data from the Response Cache.


        :param read_timeout_in_ms: The read_timeout_in_ms of this ExternalRespCache.
        :type: int
        """
        self._read_timeout_in_ms = read_timeout_in_ms

    @property
    def send_timeout_in_ms(self):
        """
        Gets the send_timeout_in_ms of this ExternalRespCache.
        Defines the timeout for transmitting data to the Response Cache.


        :return: The send_timeout_in_ms of this ExternalRespCache.
        :rtype: int
        """
        return self._send_timeout_in_ms

    @send_timeout_in_ms.setter
    def send_timeout_in_ms(self, send_timeout_in_ms):
        """
        Sets the send_timeout_in_ms of this ExternalRespCache.
        Defines the timeout for transmitting data to the Response Cache.


        :param send_timeout_in_ms: The send_timeout_in_ms of this ExternalRespCache.
        :type: int
        """
        self._send_timeout_in_ms = send_timeout_in_ms

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .secret_config import SecretConfig
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OciVaultSecretConfig(SecretConfig):
    """
    Properties used for specifying OCI vault configuration
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OciVaultSecretConfig object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.OciVaultSecretConfig.model_type` attribute
        of this class is ``OCI_VAULT_SECRET_CONFIG`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this OciVaultSecretConfig.
            Allowed values for this property are: "OCI_VAULT_SECRET_CONFIG"
        :type model_type: str

        :param secret_id:
            The value to assign to the secret_id property of this OciVaultSecretConfig.
        :type secret_id: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'secret_id': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'secret_id': 'secretId'
        }

        self._model_type = None
        self._secret_id = None
        self._model_type = 'OCI_VAULT_SECRET_CONFIG'

    @property
    def secret_id(self):
        """
        Gets the secret_id of this OciVaultSecretConfig.
        OCID of the OCI vault secret


        :return: The secret_id of this OciVaultSecretConfig.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """
        Sets the secret_id of this OciVaultSecretConfig.
        OCID of the OCI vault secret


        :param secret_id: The secret_id of this OciVaultSecretConfig.
        :type: str
        """
        self._secret_id = secret_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TableCollection(object):
    """
    Results of ListTables.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TableCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this TableCollection.
        :type items: list[oci.nosql.models.TableSummary]

        :param max_auto_reclaimable_tables:
            The value to assign to the max_auto_reclaimable_tables property of this TableCollection.
        :type max_auto_reclaimable_tables: int

        :param auto_reclaimable_tables:
            The value to assign to the auto_reclaimable_tables property of this TableCollection.
        :type auto_reclaimable_tables: int

        """
        self.swagger_types = {
            'items': 'list[TableSummary]',
            'max_auto_reclaimable_tables': 'int',
            'auto_reclaimable_tables': 'int'
        }

        self.attribute_map = {
            'items': 'items',
            'max_auto_reclaimable_tables': 'maxAutoReclaimableTables',
            'auto_reclaimable_tables': 'autoReclaimableTables'
        }

        self._items = None
        self._max_auto_reclaimable_tables = None
        self._auto_reclaimable_tables = None

    @property
    def items(self):
        """
        Gets the items of this TableCollection.
        A page of TableSummary objects.


        :return: The items of this TableCollection.
        :rtype: list[oci.nosql.models.TableSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this TableCollection.
        A page of TableSummary objects.


        :param items: The items of this TableCollection.
        :type: list[oci.nosql.models.TableSummary]
        """
        self._items = items

    @property
    def max_auto_reclaimable_tables(self):
        """
        Gets the max_auto_reclaimable_tables of this TableCollection.
        The maximum number of reclaimable tables allowed in the tenancy.


        :return: The max_auto_reclaimable_tables of this TableCollection.
        :rtype: int
        """
        return self._max_auto_reclaimable_tables

    @max_auto_reclaimable_tables.setter
    def max_auto_reclaimable_tables(self, max_auto_reclaimable_tables):
        """
        Sets the max_auto_reclaimable_tables of this TableCollection.
        The maximum number of reclaimable tables allowed in the tenancy.


        :param max_auto_reclaimable_tables: The max_auto_reclaimable_tables of this TableCollection.
        :type: int
        """
        self._max_auto_reclaimable_tables = max_auto_reclaimable_tables

    @property
    def auto_reclaimable_tables(self):
        """
        Gets the auto_reclaimable_tables of this TableCollection.
        The current number of reclaimable tables in the tenancy.


        :return: The auto_reclaimable_tables of this TableCollection.
        :rtype: int
        """
        return self._auto_reclaimable_tables

    @auto_reclaimable_tables.setter
    def auto_reclaimable_tables(self, auto_reclaimable_tables):
        """
        Sets the auto_reclaimable_tables of this TableCollection.
        The current number of reclaimable tables in the tenancy.


        :param auto_reclaimable_tables: The auto_reclaimable_tables of this TableCollection.
        :type: int
        """
        self._auto_reclaimable_tables = auto_reclaimable_tables

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReferenceSummary(object):
    """
    This is the reference summary information.
    """

    #: A constant which can be used with the type property of a ReferenceSummary.
    #: This constant has a value of "ORACLE_DATA_ASSET"
    TYPE_ORACLE_DATA_ASSET = "ORACLE_DATA_ASSET"

    #: A constant which can be used with the type property of a ReferenceSummary.
    #: This constant has a value of "ORACLE_OBJECT_STORAGE_DATA_ASSET"
    TYPE_ORACLE_OBJECT_STORAGE_DATA_ASSET = "ORACLE_OBJECT_STORAGE_DATA_ASSET"

    #: A constant which can be used with the type property of a ReferenceSummary.
    #: This constant has a value of "ORACLE_ATP_DATA_ASSET"
    TYPE_ORACLE_ATP_DATA_ASSET = "ORACLE_ATP_DATA_ASSET"

    #: A constant which can be used with the type property of a ReferenceSummary.
    #: This constant has a value of "ORACLE_ADWC_DATA_ASSET"
    TYPE_ORACLE_ADWC_DATA_ASSET = "ORACLE_ADWC_DATA_ASSET"

    #: A constant which can be used with the type property of a ReferenceSummary.
    #: This constant has a value of "MYSQL_DATA_ASSET"
    TYPE_MYSQL_DATA_ASSET = "MYSQL_DATA_ASSET"

    #: A constant which can be used with the type property of a ReferenceSummary.
    #: This constant has a value of "GENERIC_JDBC_DATA_ASSET"
    TYPE_GENERIC_JDBC_DATA_ASSET = "GENERIC_JDBC_DATA_ASSET"

    def __init__(self, **kwargs):
        """
        Initializes a new ReferenceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this ReferenceSummary.
        :type key: str

        :param name:
            The value to assign to the name property of this ReferenceSummary.
        :type name: str

        :param identifier:
            The value to assign to the identifier property of this ReferenceSummary.
        :type identifier: str

        :param identifier_path:
            The value to assign to the identifier_path property of this ReferenceSummary.
        :type identifier_path: str

        :param description:
            The value to assign to the description property of this ReferenceSummary.
        :type description: str

        :param type:
            The value to assign to the type property of this ReferenceSummary.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param target_object:
            The value to assign to the target_object property of this ReferenceSummary.
        :type target_object: object

        :param aggregator_key:
            The value to assign to the aggregator_key property of this ReferenceSummary.
        :type aggregator_key: str

        :param used_by:
            The value to assign to the used_by property of this ReferenceSummary.
        :type used_by: list[oci.data_integration.models.ReferenceUsedBy]

        :param child_references:
            The value to assign to the child_references property of this ReferenceSummary.
        :type child_references: list[oci.data_integration.models.ChildReference]

        """
        self.swagger_types = {
            'key': 'str',
            'name': 'str',
            'identifier': 'str',
            'identifier_path': 'str',
            'description': 'str',
            'type': 'str',
            'target_object': 'object',
            'aggregator_key': 'str',
            'used_by': 'list[ReferenceUsedBy]',
            'child_references': 'list[ChildReference]'
        }

        self.attribute_map = {
            'key': 'key',
            'name': 'name',
            'identifier': 'identifier',
            'identifier_path': 'identifierPath',
            'description': 'description',
            'type': 'type',
            'target_object': 'targetObject',
            'aggregator_key': 'aggregatorKey',
            'used_by': 'usedBy',
            'child_references': 'childReferences'
        }

        self._key = None
        self._name = None
        self._identifier = None
        self._identifier_path = None
        self._description = None
        self._type = None
        self._target_object = None
        self._aggregator_key = None
        self._used_by = None
        self._child_references = None

    @property
    def key(self):
        """
        Gets the key of this ReferenceSummary.
        The reference's key, key of the object that is being used by a published object or its dependents.


        :return: The key of this ReferenceSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ReferenceSummary.
        The reference's key, key of the object that is being used by a published object or its dependents.


        :param key: The key of this ReferenceSummary.
        :type: str
        """
        self._key = key

    @property
    def name(self):
        """
        Gets the name of this ReferenceSummary.
        The name of reference object.


        :return: The name of this ReferenceSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReferenceSummary.
        The name of reference object.


        :param name: The name of this ReferenceSummary.
        :type: str
        """
        self._name = name

    @property
    def identifier(self):
        """
        Gets the identifier of this ReferenceSummary.
        The identifier of reference object.


        :return: The identifier of this ReferenceSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this ReferenceSummary.
        The identifier of reference object.


        :param identifier: The identifier of this ReferenceSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def identifier_path(self):
        """
        Gets the identifier_path of this ReferenceSummary.
        The identifier path of reference object.


        :return: The identifier_path of this ReferenceSummary.
        :rtype: str
        """
        return self._identifier_path

    @identifier_path.setter
    def identifier_path(self, identifier_path):
        """
        Sets the identifier_path of this ReferenceSummary.
        The identifier path of reference object.


        :param identifier_path: The identifier_path of this ReferenceSummary.
        :type: str
        """
        self._identifier_path = identifier_path

    @property
    def description(self):
        """
        Gets the description of this ReferenceSummary.
        The description of reference object.


        :return: The description of this ReferenceSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReferenceSummary.
        The description of reference object.


        :param description: The description of this ReferenceSummary.
        :type: str
        """
        self._description = description

    @property
    def type(self):
        """
        Gets the type of this ReferenceSummary.
        The type of reference object.

        Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this ReferenceSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ReferenceSummary.
        The type of reference object.


        :param type: The type of this ReferenceSummary.
        :type: str
        """
        allowed_values = ["ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def target_object(self):
        """
        Gets the target_object of this ReferenceSummary.
        The target object referenced. References are made to data assets and child references are made to connections. The type defining this reference is mentioned in the property type.


        :return: The target_object of this ReferenceSummary.
        :rtype: object
        """
        return self._target_object

    @target_object.setter
    def target_object(self, target_object):
        """
        Sets the target_object of this ReferenceSummary.
        The target object referenced. References are made to data assets and child references are made to connections. The type defining this reference is mentioned in the property type.


        :param target_object: The target_object of this ReferenceSummary.
        :type: object
        """
        self._target_object = target_object

    @property
    def aggregator_key(self):
        """
        Gets the aggregator_key of this ReferenceSummary.
        The aggregator of reference object.


        :return: The aggregator_key of this ReferenceSummary.
        :rtype: str
        """
        return self._aggregator_key

    @aggregator_key.setter
    def aggregator_key(self, aggregator_key):
        """
        Sets the aggregator_key of this ReferenceSummary.
        The aggregator of reference object.


        :param aggregator_key: The aggregator_key of this ReferenceSummary.
        :type: str
        """
        self._aggregator_key = aggregator_key

    @property
    def used_by(self):
        """
        Gets the used_by of this ReferenceSummary.
        List of published objects where this is used.


        :return: The used_by of this ReferenceSummary.
        :rtype: list[oci.data_integration.models.ReferenceUsedBy]
        """
        return self._used_by

    @used_by.setter
    def used_by(self, used_by):
        """
        Sets the used_by of this ReferenceSummary.
        List of published objects where this is used.


        :param used_by: The used_by of this ReferenceSummary.
        :type: list[oci.data_integration.models.ReferenceUsedBy]
        """
        self._used_by = used_by

    @property
    def child_references(self):
        """
        Gets the child_references of this ReferenceSummary.
        List of references that are dependent on this reference.


        :return: The child_references of this ReferenceSummary.
        :rtype: list[oci.data_integration.models.ChildReference]
        """
        return self._child_references

    @child_references.setter
    def child_references(self, child_references):
        """
        Sets the child_references of this ReferenceSummary.
        List of references that are dependent on this reference.


        :param child_references: The child_references of this ReferenceSummary.
        :type: list[oci.data_integration.models.ChildReference]
        """
        self._child_references = child_references

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApiValidationDetail(object):
    """
    Detail of a single error or warning.
    """

    #: A constant which can be used with the severity property of a ApiValidationDetail.
    #: This constant has a value of "INFO"
    SEVERITY_INFO = "INFO"

    #: A constant which can be used with the severity property of a ApiValidationDetail.
    #: This constant has a value of "WARNING"
    SEVERITY_WARNING = "WARNING"

    #: A constant which can be used with the severity property of a ApiValidationDetail.
    #: This constant has a value of "ERROR"
    SEVERITY_ERROR = "ERROR"

    def __init__(self, **kwargs):
        """
        Initializes a new ApiValidationDetail object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param msg:
            The value to assign to the msg property of this ApiValidationDetail.
        :type msg: str

        :param severity:
            The value to assign to the severity property of this ApiValidationDetail.
            Allowed values for this property are: "INFO", "WARNING", "ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        :param src:
            The value to assign to the src property of this ApiValidationDetail.
        :type src: list[list[float]]

        """
        self.swagger_types = {
            'msg': 'str',
            'severity': 'str',
            'src': 'list[list[float]]'
        }

        self.attribute_map = {
            'msg': 'msg',
            'severity': 'severity',
            'src': 'src'
        }

        self._msg = None
        self._severity = None
        self._src = None

    @property
    def msg(self):
        """
        Gets the msg of this ApiValidationDetail.
        Description of the warning/error.


        :return: The msg of this ApiValidationDetail.
        :rtype: str
        """
        return self._msg

    @msg.setter
    def msg(self, msg):
        """
        Sets the msg of this ApiValidationDetail.
        Description of the warning/error.


        :param msg: The msg of this ApiValidationDetail.
        :type: str
        """
        self._msg = msg

    @property
    def severity(self):
        """
        Gets the severity of this ApiValidationDetail.
        Severity of the issue.

        Allowed values for this property are: "INFO", "WARNING", "ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this ApiValidationDetail.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this ApiValidationDetail.
        Severity of the issue.


        :param severity: The severity of this ApiValidationDetail.
        :type: str
        """
        allowed_values = ["INFO", "WARNING", "ERROR"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    @property
    def src(self):
        """
        Gets the src of this ApiValidationDetail.
        Position of the issue in the specification file (line, column).


        :return: The src of this ApiValidationDetail.
        :rtype: list[list[float]]
        """
        return self._src

    @src.setter
    def src(self, src):
        """
        Sets the src of this ApiValidationDetail.
        Position of the issue in the specification file (line, column).


        :param src: The src of this ApiValidationDetail.
        :type: list[list[float]]
        """
        self._src = src

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
